==> Zombie-Villager-Variants-1.0.0-sources.jar: fun/wich/client/DrownedVillagerOverlayFeatureRenderer.java <==
package fun.wich.client;

import fun.wich.ZombieVillagerVariants;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10087;
import net.minecraft.class_11659;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_5599;
import net.minecraft.class_619;

@Environment(value= EnvType.CLIENT)
public class DrownedVillagerOverlayFeatureRenderer extends class_3887<class_10087, class_619<class_10087>> {
	public static final class_2960 SKIN = class_2960.method_60655(ZombieVillagerVariants.MOD_ID,"textures/entity/drowned_villager/drowned_villager_outer_layer.png");
	private final DilatedZombieVillagerEntityModel model;
	private final DilatedZombieVillagerEntityModel babyModel;

	public DrownedVillagerOverlayFeatureRenderer(class_3883<class_10087, class_619<class_10087>> context, class_5599 loader) {
		super(context);
		this.model = new DilatedZombieVillagerEntityModel(loader.method_32072(ModClient.DROWNED_VILLAGER_OUTER));
		this.babyModel = new DilatedZombieVillagerEntityModel(loader.method_32072(ModClient.DROWNED_VILLAGER_BABY_OUTER));
	}

	@Override
	public void render(class_4587 matrixStack, class_11659 orderedRenderCommandQueue, int i, class_10087 zombieEntityRenderState, float f, float g) {
		DilatedZombieVillagerEntityModel drownedEntityModel = zombieEntityRenderState.field_53457 ? this.babyModel : this.model;
		method_23196(drownedEntityModel, SKIN, matrixStack, orderedRenderCommandQueue, i, zombieEntityRenderState, -1, 1);
	}
}

==> Zombie-Villager-Variants-1.1.2-sources.jar: fun/wich/client/DrownedVillagerOverlayFeatureRenderer.java <==
package fun.wich.client;

import fun.wich.ZombieVillagerVariants;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10087;
import net.minecraft.class_11659;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_5599;
import net.minecraft.class_619;

@Environment(value= EnvType.CLIENT)
public class DrownedVillagerOverlayFeatureRenderer extends class_3887<class_10087, class_619<class_10087>> {
	public static final class_2960 SKIN = class_2960.method_60655(ZombieVillagerVariants.MOD_ID,"textures/entity/drowned_villager/drowned_villager_outer_layer.png");
	private final DilatedZombieVillagerEntityModel model;
	private final DilatedZombieVillagerEntityModel babyModel;

	public DrownedVillagerOverlayFeatureRenderer(class_3883<class_10087, class_619<class_10087>> context, class_5599 loader) {
		super(context);
		this.model = new DilatedZombieVillagerEntityModel(loader.method_32072(ZombieVillagerVariantsClient.DROWNED_VILLAGER_OUTER));
		this.babyModel = new DilatedZombieVillagerEntityModel(loader.method_32072(ZombieVillagerVariantsClient.DROWNED_VILLAGER_BABY_OUTER));
	}

	@Override
	public void render(class_4587 matrixStack, class_11659 orderedRenderCommandQueue, int i, class_10087 zombieEntityRenderState, float f, float g) {
		DilatedZombieVillagerEntityModel drownedEntityModel = zombieEntityRenderState.field_53457 ? this.babyModel : this.model;
		method_23196(drownedEntityModel, SKIN, matrixStack, orderedRenderCommandQueue, i, zombieEntityRenderState, -1, 1);
	}
}
